﻿# -*- coding: utf-8 -*-
#Projektarbeit: Automatisierte Kartenerstellung für MAKOs in ArcGIS10 mittels Python-Programmierung
#Erstellt im Rahmen der Zusatzqualifikation „Geographische Informationssysteme“ 2011/2012 - GIS-Trainees
#Autor: K.Fleckenstein 2012
#Thema: Automatisiert über ein Tool werden MAKO-Bestandskarten erstellt
#Auftraggeber: LANUV NRW, Abteilung 2, Fachbereich 23 
#modifiziert 25.02.2013 in Rücksprache mit M. Erzner, EDV-Servicestelle der Biologischen Stationen NRW (0281-96252-19)
#Modifikation erfolgte zur Anpassung an die Umgebung von ArcGIS 10.1


#MODULE-----------------------------------------------------------------------------------------------------------------------------------------------
import arcpy, os, datetime

#PARAMETER-----------------------------------------------------------------------------------------------------------------------------------------------
Gebietsname = arcpy.GetParameterAsText(0)

#JOIN TABLE-FOLDERPATH:
table_export_folder = arcpy.GetParameterAsText(1)

#INPUT SHAPEFILES:
df_export_shp= arcpy.GetParameterAsText(2)
dp_export_shp= arcpy.GetParameterAsText(3)
dl_export_shp= arcpy.GetParameterAsText(4)

#MXD VORLAGE, SYMBOLOGIE_LAYER, LOGO:
mxd_path = arcpy.GetParameterAsText(5)
bt_symbology_lyr = arcpy.GetParameterAsText(6)
logo_path = arcpy.GetParameterAsText(7)

#AUSGABEORDNER/WORKSPACE:
path= arcpy.GetParameterAsText(8)

#=======================================================================================================================================================
#WORKSPACE-----------------------------------------------------------------------------------------------------------------------------------------------
arcpy.env.overwriteOutput = True
arcpy.env.workspace = path 
print arcpy.env.workspace

''' GELÖSCHT:
coordinate_path = os.path.join(arcpy.GetInstallInfo()["InstallDir"], "Coordinate Systems\Projected Coordinate Systems\UTM\Europe")
print coordinate_path
'''

'''EINGEFÜGT:
# SET OUTPUT COORDINATE SYSTEM
outCS = arcpy.SpatialReference('ETRS 1989 UTM Zone 32N')
'''

# SET OUTPUT COORDINATE SYSTEM
outCS = arcpy.SpatialReference('ETRS 1989 UTM Zone 32N')

# Ursprüngliche Feldnamen (Spaltennamen) werden beim Join von Shapefile und Tabelle beibehalten, ohne dass der Name der Ursprungstabelle vorangestellt wird
arcpy.env.qualifiedFieldNames = "UNQUALIFIED"

#VARIABLEN-----------------------------------------------------------------------------------------------------------------------------------------------
#MXDs
Datum = str(datetime.date.today()).replace("-","_") #Heutiges Datum mit im Format "Jahr_Monat_Tag"
Ergebnis_MXD_Name = "Bestandskarte" + "_" + Gebietsname + "_" + Datum + ".mxd"
print Ergebnis_MXD_Name

#DATENORDNER
folder_name = "Bestandskarte" + "_" + Gebietsname + "_" + Datum + "_Daten_ETRS"
folder_path =  path + os.sep + folder_name

#----JOIN SACHDATEN MIT GEODATEN--------------------------
#JOIN TABLES:
table_mako_bt = table_export_folder + os.sep + "mako-bt.dbf" 
table_mako_fp = table_export_folder + os.sep + "mako-fp.dbf"
table_mako_ft = table_export_folder + os.sep + "mako-ft.dbf"

#ETRS SHAPEFILES:
df_export_shp_ETRS = folder_path + os.sep + Gebietsname + "_" + df_export_shp[len(df_export_shp)-6:len(df_export_shp)-4] + "_ETRS.shp"
dp_export_shp_ETRS = folder_path + os.sep + Gebietsname + "_"+ dp_export_shp[len(dp_export_shp)-6:len(dp_export_shp)-4] + "_ETRS.shp"
if arcpy.Exists(dl_export_shp): 
  dl_export_shp_ETRS = folder_path + os.sep + Gebietsname + "_"+ dl_export_shp[len(dl_export_shp)-6:len(dl_export_shp)-4] + "_ETRS.shp"
else:
  dl_export_shp_ETRS=""

#JOIN OUTPUT SHAPEFILES:
join_bt = folder_path + os.sep + "mako_bt_df.shp"
join_fp_df = folder_path + os.sep + "mako_fp_df.shp"
join_ft_df = folder_path + os.sep + "mako_ft_df.shp"
join_fp_dp = folder_path + os.sep + "mako_fp_dp.shp"
join_ft_dp = folder_path + os.sep + "mako_ft_dp.shp"
join_dl = folder_path + os.sep + "mako_dl.shp"

joinField = "KENNUNG"
drop_fields = [joinField+"_1"] 

#WEITERE NEUE SHAPEFILES
FFH_Shape = folder_path + os.sep + "mako_FFH_Grenze.shp"
GB_Shape_temp = folder_path + os.sep + "mako_GB_Grenze_temp.shp"
GB_Shape = folder_path + os.sep + "mako_GB_Grenze.shp"
LRT_Shape = folder_path + os.sep + "mako_LRT_Grenze.shp"
BEEINTR_Shape_temp = folder_path + os.sep + "mako_Beeintr_temp.shp"
BEEINTR_table ="mako_Beeintr_table.dbf"
BEEINTR_Shape = folder_path + os.sep + "mako_Beeintr.shp"

#=======================================================================================================================================================
#FUNKTIONEN-----------------------------------------------------------------------------------------------------------------------------------------------
def newLine(): 
  return "\n"
  
#FUNKTION UM SACHDATEN MIT GEODATEN ZU VERKNÜPFEN
def addJoin(in_fc, joinField, join_table, join_type, out_fc, drop_fields):
    #JOIN DER SACHTABELLEN AN DAS SHAPEFILE 
    temp_layer = "temp.lyr"
    arcpy.MakeFeatureLayer_management (in_fc, temp_layer)
    arcpy.AddJoin_management (temp_layer, joinField, join_table, joinField, join_type)
    #ERZEUGEN EINER NEUEN FC AUS DEM TEMPORAEREN JOIN
    arcpy.CopyFeatures_management(temp_layer, out_fc)
    arcpy.DeleteField_management (out_fc, drop_fields)
    del temp_layer

#FUNKTION UM NEUEN ORDNER ANZULEGEN
def CreateNewFolder(current_workspace, folder_name):
    Liste = arcpy.ListFiles() 
    if folder_name not in Liste:
        arcpy.CreateFolder_management(arcpy.env.workspace, folder_name)       
'''GELÖSCHT:	
#FUNKTION ZUM TRANSFORMIEREN VON GAUSS-KRUEGER IN ETRS89
def transformation(fc):
    desc = arcpy.Describe(fc)
    coordinate = str(int(desc.extent.XMax))
    coordinate_system = desc.SpatialReference.name
    print desc.SpatialReference.name
    if len(coordinate) == 7:
        if coordinate[:1] in ["2", "3", "4", "5"]:
            if coordinate_system[:len(coordinate_system)-2] == "DHDN_3_Degree_Gauss_Zone" or coordinate_system[:len(coordinate_system)-2] == "Germany_Zone":
                #TEMP & REAL NAMEN ERZEUGEN 
                out_name = folder_path + os.sep + Gebietsname + "_" + fc[len(fc)-6:len(fc)-4] + "_ETRS.shp"
                #TRANSFORMIEREN
                arcpy.Project_management (fc, out_name, coordinate_path + os.sep +  "ETRS 1989 UTM Zone 32N.prj", "DHDN_To_ETRS_1989_8_NTv2")                
    del desc, coordinate, coordinate_system
'''		
'''EINGEFÜGT:
#FUNKTION ZUM TRANSFORMIEREN VON GAUSS-KRUEGER IN ETRS89
def transformation(fc):
    desc = arcpy.Describe(fc)
    coordinate = str(int(desc.extent.XMax))
    coordinate_system = desc.SpatialReference.name
    print desc.SpatialReference.name
    if len(coordinate) == 7:
        if coordinate[:1] in ["2", "3", "4", "5"]:
            if coordinate_system[:len(coordinate_system)-2] == "DHDN_3_Degree_Gauss_Zone" or coordinate_system[:len(coordinate_system)-2] == "Germany_Zone":
                #TEMP & REAL NAMEN ERZEUGEN 
                out_name = folder_path + os.sep + Gebietsname + "_" + fc[len(fc)-6:len(fc)-4] + "_ETRS.shp"
                #TRANSFORMIEREN
                arcpy.Project_management (fc, out_name, outCS, "DHDN_To_ETRS_1989_8_NTv2")          
    del desc, coordinate, coordinate_system
	'''

#FUNKTION ZUM TRANSFORMIEREN VON GAUSS-KRUEGER IN ETRS89
def transformation(fc):
    desc = arcpy.Describe(fc)
    coordinate = str(int(desc.extent.XMax))
    coordinate_system = desc.SpatialReference.name
    print desc.SpatialReference.name
    if len(coordinate) == 7:
        if coordinate[:1] in ["2", "3", "4", "5"]:
            if coordinate_system[:len(coordinate_system)-2] == "DHDN_3_Degree_Gauss_Zone" or coordinate_system[:len(coordinate_system)-2] == "Germany_Zone":
                #TEMP & REAL NAMEN ERZEUGEN 
                out_name = folder_path + os.sep + Gebietsname + "_" + fc[len(fc)-6:len(fc)-4] + "_ETRS.shp"
                #TRANSFORMIEREN
                arcpy.Project_management (fc, out_name, outCS, "DHDN_To_ETRS_1989_8_NTv2")         
    del desc, coordinate, coordinate_system
    
    
#FUNKTION ZUM ERZEUGEN NEUER SHAPEFILES AUS DEM EXPORT SHAPEFILE ÜBER SELEKTION
def NewShapeFromSelection(in_shape, where_clause, out_shape, label):       
    #LAYER ERZEUGEN ÜBER SELEKTION
    temp_layer = "temp.lyr"
    arcpy.MakeFeatureLayer_management (in_shape, temp_layer)
    arcpy.SelectLayerByAttribute_management (temp_layer, "NEW_SELECTION", where_clause)

    #ERZEUGEN EINER NEUEN FC AUS DEM TEMPORAEREN LAYER
    arcpy.CopyFeatures_management(temp_layer, out_shape)
    del temp_layer

    #NEUE SPALTE EINFÜGEN UND BESCHRIFTUNGSTEXT ÜBER UPDATE-CURSOR EINTRAGEN
    arcpy.AddField_management(out_shape, "NAME", "TEXT")
    rows= arcpy.UpdateCursor(out_shape, "", "", "NAME")
    for row in rows:
        row.setValue("NAME", label)
        rows.updateRow(row)
        del row
    del rows
    
#FUNKTION UM MEHRFACH VORKOMMENDE WERTE IN EINER LISTE ZU LÖSCHEN UND DIE LISTE ALPHABETISCH ZU SORTIEREN
def RemoveDuplicates(wordList):
    wordList2 =[]
    for word in wordList:
        if word not in wordList2 and word not in " ,;":         
            wordList2.append(word)
    wordList2.sort()
    return wordList2
  
#FUNKTION ZUM AUSLESEN VON SPALTEN, ERZEUGEN EINER LISTE FÜR DYNAMISCHE LEGENDEN-TEXTE
def Spalte_auslesen(Shapefile, Spalte):
    rows = arcpy.SearchCursor(Shapefile) 
    Liste=[]
    for row in rows:
        Liste_Zeile = row.getValue(Spalte).split(";")#TRENNUNG DER 1:N BEZIEHUNGEN
        for Eintrag in Liste_Zeile:
            Liste.append(Eintrag.strip())   
    del rows
    return Liste

#FUNKTION ZUM ERSTELLEN EINES LEGENDEN-TEXTES AUS EINER LISTE, DUPLIKATE WERDEN ENTFERNT, PRO EINTRAG DER LISTE --> EINE NEUE ZEILE 
def Textfeld_aus_Liste(Liste):
    Text= ""
    for Eintrag in Liste:
        Text = Text + Eintrag + newLine() 
    return Text

#FUNKTION UM AUS DEM AKTUELLEN MASSTAB  DER KARTE, DER AUS DEM ZOOM AUF DIE AUSSENGRENZEN DES BT_LAYERS ENTSTEHT, EINEN AUFGERUNDETE GANZAHLIGEN MASSTBAB ZU ERMITTELN
def newScale(scale):
    scale_first_nr_plus1 = str(int(str(int(scale))[0])+1)
    scale_nulls =""
    for index in range(len(str(int(scale)))-1):
        scale_nulls = scale_nulls + "0"
    new_scale = int(scale_first_nr_plus1 + scale_nulls)
    return new_scale

#===========================================================================================================================================================
# 1) NEUEN ORDNER ERSTELLEN
CreateNewFolder(arcpy.env.workspace, folder_name)
out_name = df_export_shp[:len(df_export_shp)-4] + "_ETRS.shp"

#=======================================================================================================================================================
# 2) TRANSFORMATION DER GEODATEN IN ETRS89, FALLS SIE IN GAUß-KRUEGER VORLIEGEN UND EXISTIEREN
if arcpy.Exists(df_export_shp):
    transformation(df_export_shp)
if arcpy.Exists(dp_export_shp):
    transformation(dp_export_shp)
if arcpy.Exists(dl_export_shp):
    transformation(dl_export_shp)

#=======================================================================================================================================================
# 3) JOIN DER SACHTABELLEN AN DAS SHAPEFILE --> ERZEUGEN VON NEUEN SHAPEFILES
if arcpy.Exists(df_export_shp_ETRS):
    addJoin(df_export_shp_ETRS, joinField, table_mako_bt, "KEEP_COMMON", join_bt, drop_fields)
    addJoin(df_export_shp_ETRS, joinField, table_mako_ft, "KEEP_COMMON", join_ft_df, drop_fields)
    addJoin(df_export_shp_ETRS, joinField, table_mako_fp, "KEEP_COMMON", join_fp_df, drop_fields)
elif arcpy.Exists(df_export_shp):
    addJoin(df_export_shp, joinField, table_mako_bt, "KEEP_COMMON", join_bt, drop_fields)
    addJoin(df_export_shp, joinField, table_mako_ft, "KEEP_COMMON", join_ft_df, drop_fields)
    addJoin(df_export_shp, joinField, table_mako_fp, "KEEP_COMMON", join_fp_df, drop_fields)

if arcpy.Exists(dp_export_shp_ETRS):    
    addJoin(dp_export_shp_ETRS, joinField, table_mako_ft, "KEEP_COMMON", join_ft_dp, drop_fields)
    addJoin(dp_export_shp_ETRS, joinField, table_mako_fp, "KEEP_COMMON", join_fp_dp, drop_fields)
elif arcpy.Exists(dp_export_shp):
    addJoin(dp_export_shp, joinField, table_mako_ft, "KEEP_COMMON", join_ft_dp, drop_fields)
    addJoin(dp_export_shp, joinField, table_mako_fp, "KEEP_COMMON", join_fp_dp, drop_fields)

if arcpy.Exists(dl_export_shp_ETRS):    
    addJoin(dl_export_shp_ETRS, joinField, table_mako_bt, "KEEP_ALL", join_dl, drop_fields)
elif arcpy.Exists(dl_export_shp):
    addJoin(dl_export_shp, joinField, table_mako_bt, "KEEP_ALL", join_dl, drop_fields)
    
#=======================================================================================================================================================
# 4) ERZEUGEN NEUER SHAPEFILES DURCH SELEKTION VON BESTIMMTEN DATEN AUS EXPORT_SHAPEFILES 

# a) FFH-GRENZE --> NEUES SHAPEFILES ERZEUGEN-----------------------------------------------------------------------------------------------------

if arcpy.Exists(df_export_shp_ETRS):
    NewShapeFromSelection(df_export_shp_ETRS, "KENNUNG LIKE 'DE-%'", FFH_Shape, "Grenze FFH-Gebiet")
elif arcpy.Exists(df_export_shp):
    NewShapeFromSelection(df_export_shp, "KENNUNG LIKE 'DE-%'", FFH_Shape, "Grenze FFH-Gebiet")

# b) FFH-LRT-GEBIETE --> NEUES SHAPEFILES ERZEUGEN------------------------------------------------------------------------------------------------
NewShapeFromSelection(join_bt, "BTYP_K LIKE 'x%' OR BTYP_K LIKE 'z%' ", LRT_Shape, "FFH-Lebensraumtyp")

# c) BEEINTRÄCHTIGUNGEN --> NEUES SHAPEFILES ERZEUGEN----------------------------------------------------------------------------------------------
NewShapeFromSelection(join_bt, "BEEINTR NOT LIKE ' '", BEEINTR_Shape_temp, "Beeinträchtigung")

# MITTELPUNKTE DER BT-FLÄCHEN ERRECHNEN 
arcpy.AddField_management(BEEINTR_Shape_temp, "X_CENTR", "DOUBLE")
arcpy.AddField_management(BEEINTR_Shape_temp, "Y_CENTR", "DOUBLE")
arcpy.CalculateField_management(BEEINTR_Shape_temp, "X_CENTR", "!SHAPE.CENTROID!.split()[0]","PYTHON")
arcpy.CalculateField_management(BEEINTR_Shape_temp, "Y_CENTR", "!SHAPE.CENTROID!.split()[1]","PYTHON")

# XY-TABELLE ERZEUGEN
temp_layer = "BEEINTR_temp.lyr"
arcpy.MakeFeatureLayer_management (BEEINTR_Shape_temp, temp_layer)
arcpy.TableToTable_conversion(temp_layer,folder_path, BEEINTR_table)

# AUS XY-TABELLE NEUES PUNKT_SHAPEFILE ERZEUGEN
temp_layer = "BEEINTR_temp2.lyr"
arcpy.MakeXYEventLayer_management(folder_path + os.sep + BEEINTR_table, "X_CENTR", "Y_CENTR", temp_layer, os.sep +  "ETRS 1989 UTM Zone 32N.prj")
arcpy.CopyFeatures_management(temp_layer, BEEINTR_Shape)

#TEMPORÄRES SHAPEFILE UND XY_TABELLE WIEDER LÖSCHEN
if arcpy.Exists(BEEINTR_Shape_temp):
    arcpy.Delete_management (BEEINTR_Shape_temp)
if arcpy.Exists(folder_path + os.sep + BEEINTR_table):
    arcpy.Delete_management (folder_path + os.sep +BEEINTR_table)
del BEEINTR_Shape_temp, BEEINTR_table, temp_layer #NICHT MEHR BENÖTIGTE VARIABLE LÖSCHEN

##arcpy.FeatureToPoint_management(BEEINTR_Shape_temp, BEEINTR_Shape, "INSIDE") --> Geht nur bei ArcInfo Lizenzen

# d) GB_GRENZEN, NEUES SHAPEFILES ERZEUGEN-------------------------------------------------------------------------------------------------------
if arcpy.Exists(df_export_shp_ETRS):
    NewShapeFromSelection(df_export_shp_ETRS, "KENNUNG LIKE 'GB-%'", GB_Shape_temp, "§ 62 Biotop")
elif arcpy.Exists(df_export_shp):
    NewShapeFromSelection(df_export_shp, "KENNUNG LIKE 'GB-%'", GB_Shape_temp, "§ 62 Biotop")
#SPATIAL JOIN BT --> GB
arcpy.SpatialJoin_analysis (GB_Shape_temp, join_bt, GB_Shape, "","","","CONTAINS")

#NICHT BENÖTIGTE FELDER (SPALTEN) RAUSLÖSCHEN
FieldList= arcpy.ListFields(GB_Shape)
dropFieldList=[]
for field in FieldList:
    if field.name not in ["FID", "Shape","KENNUNG", "GISPADID", "KLASSE", "GEOFUNK", "NAME", "KENNUNG_1", "P62_TYP_K", "P62_TYP"]:
        dropFieldList.append(field.name)
arcpy.DeleteField_management(GB_Shape, dropFieldList)

#TEMPORÄRES SHAPEFILE LÖSCHEN
if arcpy.Exists(GB_Shape_temp):
    arcpy.Delete_management (GB_Shape_temp)
del GB_Shape_temp

#===========================================================================================================================================================
# 5) AUTOMATISIERTE KARTENERSTELLUNG 

# a) MXD LADEN-------------------------------------------------------------------------------------------------------------------------------------
mxd = arcpy.mapping.MapDocument(mxd_path)
mxd.activeView = "PAGE_LAYOUT"

# b)REPAIR WORKSPACE
mxd.findAndReplaceWorkspacePaths("", folder_path)

# c) DATAFRAME-------------------------------------------------------------------------------------------------------------------------------------
df = arcpy.mapping.ListDataFrames(mxd)[0]

# d) AUSWAHL, ZOOM DES DATAFRAMES AUF DEN BIOTOPTYPEN-BESTAND-LAYER, FESTLEGEN DES BEZUGSMAßSTABS------------------------------------------------
for lyr in arcpy.mapping.ListLayers(mxd, "", df):
    #ZOOM
    if lyr.name == "Biotoptypen_Bestand":
        arcpy.SelectLayerByAttribute_management (lyr, "NEW_SELECTION")
        df.zoomToSelectedFeatures()
        arcpy.SelectLayerByAttribute_management (lyr, "CLEAR_SELECTION")
        if arcpy.Exists(bt_symbology_lyr):          
            arcpy.ApplySymbologyFromLayer_management(lyr, bt_symbology_lyr)

df.scale = newScale(df.scale)
df.referenceScale = df.scale
print int(df.scale)

if arcpy.Exists(dl_export_shp):
    arcpy.MakeFeatureLayer_management(join_dl, "dl_export")
    add_layer = arcpy.mapping.Layer("dl_export")
    arcpy.mapping.AddLayer(df, add_layer, "TOP")

# e) DYNAMISCHE TEXTE FÜR DIE KARTEN_LEGENDE ERSTELLEN-------------------------------------------------------------------------------------------

#FFH-KENNUNG AUSLESEN UND IN VARIABLE SPEICHERN FÜR DYNAMISCHEN TEXT 
rows = arcpy.SearchCursor(FFH_Shape, "KENNUNG LIKE 'DE-%'") 
FFH_KENNUNG=""
for row in rows:
    FFH_KENNUNG = row.getValue("KENNUNG")       
print FFH_KENNUNG
del rows

#SPALTEN AUSLESEN UND IN VARIABLEN SPEICHERN FÜR DYNAMISCHE TEXTE
#TEXTFELD MIT KÜRZEL UND DEUTSCHEM NAMEN DER TIERARTEN
ft_kurz_Liste = Spalte_auslesen(table_mako_ft, "TIERART")
ft_lang_Liste = Spalte_auslesen(table_mako_ft, "TIERART_D")

Tier_Liste=[]
ft_Text_beide=""
for index in range(len(ft_lang_Liste)):
    if ft_lang_Liste[index] == " " or ft_lang_Liste[index] == "" :
        ft_Text_beide = " "
    elif len(ft_kurz_Liste) != len(ft_lang_Liste):
        ft_Text_beide = "N/A" + " " + ft_lang_Liste[index]
    elif ft_kurz_Liste[index] == "" or ft_kurz_Liste[index] == " ":
        ft_Text_beide = "N/A" + " " + ft_lang_Liste[index]
    else:
        ft_Text_beide = ft_kurz_Liste[index] + " " + ft_lang_Liste[index]
    Tier_Liste.append (ft_Text_beide)
del ft_Text_beide   

ft_lang_Liste=[]
ft_kurz_Liste=[]
for Eintrag in RemoveDuplicates(Tier_Liste):
    index =Eintrag.find(" ")
    ft_lang_Liste.append(Eintrag[index+1:])
    ft_kurz_Liste.append(Eintrag[:index])

ft_lang_Text = Textfeld_aus_Liste(ft_lang_Liste)#LANGNAMEN DER TIERARTEN
ft_kurz_Text = Textfeld_aus_Liste(ft_kurz_Liste)#KÜRZEL DER TIERARTEN

#TEXTFELD MIT KÜRZEL UND WISSENSCHAFTLICHEM NAMEN DER PFLANZENARTEN
fp_kurz_Liste = Spalte_auslesen(table_mako_fp, "PFL_ART")
fp_lang_Liste = Spalte_auslesen(table_mako_fp, "PFL_ART_W")

Pflanzen_Liste=[]
fp_Text_beide =""
for index in range(len(fp_lang_Liste)):
    if fp_lang_Liste[index] == " " or fp_lang_Liste[index] == "" :
        fp_Text_beide = " "
    elif len(fp_kurz_Liste) != len(fp_lang_Liste):
        fp_Text_beide = "N/A" + " " + fp_lang_Liste[index]
    elif fp_kurz_Liste[index] == "" or fp_kurz_Liste[index] == " ":
        fp_Text_beide = "N/A" + " " + fp_lang_Liste[index]
    else:
        fp_Text_beide = fp_kurz_Liste[index] + " " + fp_lang_Liste[index]
    Pflanzen_Liste.append (fp_Text_beide)
del fp_Text_beide     

fp_lang_Liste=[]
fp_kurz_Liste=[]
for Eintrag in RemoveDuplicates(Pflanzen_Liste):
    index =Eintrag.find(" ")
    fp_lang_Liste.append(Eintrag[index+1:])
    fp_kurz_Liste.append(Eintrag[:index])
fp_lang_Text = Textfeld_aus_Liste(fp_lang_Liste)#LANGNAMEN DER PLFANZENARTEN
fp_kurz_Text = Textfeld_aus_Liste(fp_kurz_Liste)#KÜRZEL DER PFLANZENARTEN


#DYNAMISCHEN TEXT FÜR BEEINTRÄCHTIGUNGEN
BEEINTR_K = Spalte_auslesen(BEEINTR_Shape, "BEEINTR_K")
BEEINTR = Spalte_auslesen(BEEINTR_Shape, "BEEINTR")
BEEINTR_Liste=[]
print  BEEINTR_K
for index in range(len(BEEINTR_K)):
  if BEEINTR_K[index] == "":    
      BEEINTR_Liste.append("?" + "  " + BEEINTR[index])
  elif BEEINTR_K[index] == " ":    
      BEEINTR_Liste.append("?" + "  " + BEEINTR[index])
  else:
      BEEINTR_Liste.append(BEEINTR_K[index] + "  " + BEEINTR[index])
del BEEINTR_K, BEEINTR

BEEINTR_Liste = RemoveDuplicates(BEEINTR_Liste)

BEEINTR_Text= ""
BEEINTR_K_Text= ""
for Eintrag in BEEINTR_Liste:
    BEEINTR_Text = BEEINTR_Text + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    BEEINTR_K_Text = BEEINTR_K_Text + Eintrag[:index] + newLine()
del BEEINTR_Liste

#DYNAMISCHEN TEXT FÜR FFH-LEBENSRAUMTYPEN
rows = arcpy.SearchCursor(LRT_Shape, "LRT NOT LIKE ' '") 
LRT_Liste=[]
for row in rows:
    LRT = row.getValue("LRT")
    for index in range(len(LRT)):
        if LRT[index] == "(":
            LRT_kurz = LRT[0:index-1]
    if "Prioritaerer Lebensraum" in LRT:
        LRT_kurz = LRT_kurz + u" (prioritärer LRT)"
    LRT_K = row.getValue("LRT_K")
    LRT_Text= LRT_K + "    " + LRT_kurz
    LRT_Liste.append(LRT_Text)   

LRT_Liste = RemoveDuplicates(LRT_Liste)

LRT_Text= ""
for Eintrag in LRT_Liste:
    LRT_Text = LRT_Text + Eintrag + newLine() #+ " " + newLine()
del rows, LRT_Liste


#DYNAMISCHE TEXTE AUF KARTEN_LAYOUT AKTUALISIEREN 
for elm in arcpy.mapping.ListLayoutElements(mxd, "TEXT_ELEMENT"):
    if elm.name == "Gebietsname":
        if len(Gebietsname)!= 0:
            elm.text = Gebietsname
    elif elm.name == "Gebietsnummer":
        if len(FFH_KENNUNG)!= 0:
            elm.text = FFH_KENNUNG
    elif elm.name == "BEEINTR":
        if len(BEEINTR_Text)!= 0:
           elm.text = BEEINTR_Text
    elif elm.name == "BEEINTR_K":
        BEEIN = elm
        if len(BEEINTR_K_Text)!= 0:
            elm.text = BEEINTR_K_Text
    elif elm.name == "ft_lang":
        ft_lang = elm
        if len(ft_lang_Text)!= 0:
            elm.text = ft_lang_Text
    elif elm.name == "ft_kurz":
        ft_kurz = elm
        if len(ft_kurz_Text)!= 0:
            elm.text = ft_kurz_Text
    elif elm.name == "fp_lang":
        fp_lang = elm
        if len(fp_lang_Text)!= 0:
            elm.text = fp_lang_Text
    elif elm.name == "fp_kurz":
        fp_kurz = elm
        if len(fp_kurz_Text)!= 0:
            elm.text = fp_kurz_Text   
    elif elm.name == "LRT_Text":
        LRT = elm
        if len(LRT_Text)!= 0:
            elm.text = LRT_Text
    elif elm.name == "header_LRT":
        header_LRT = elm
    elif elm.name == "Scale":
        elm.text = "Maßstab: 1 : " + str(int(df.scale))       
del BEEINTR_Text, fp_kurz_Text, fp_lang_Text, ft_kurz_Text, ft_lang_Text, BEEINTR_K_Text, LRT_Text# NICHT MEHR BENÖTIGTE VARIABLE LÖSCHEN

# f)POSITIONIEREN DER TEXTFELDER ----------------------------------------------------------------------------------------------------------------
for elm in arcpy.mapping.ListLayoutElements(mxd, "GRAPHIC_ELEMENT", "header*"):
    if elm.name == "header_TIERE":
        header_TIERE = elm
    elif elm.name == "header_PFLANZEN":
        header_PFLANZEN = elm
        
def SetPosition(Text1, header2, Text_2, Text_K_2):
    header2.elementPositionY = Text1.elementPositionY - Text1.elementHeight - 3
    Text_2.elementPositionY = header2.elementPositionY - header2.elementHeight - 0.3
    Text_K_2.elementPositionY = Text_2.elementPositionY

try:
  SetPosition(BEEIN, header_TIERE,  ft_lang, ft_kurz)
  SetPosition(ft_lang, header_PFLANZEN,  fp_lang, fp_kurz)
  SetPosition(fp_lang, header_LRT,  LRT, LRT)
except:
  print "POSITIONIEREN FEHLGESCHLAGEN"
  
                            
# g) LEGENDE EINSTELLEN----------------------------------------------------------------------------------------------------------------
legend = arcpy.mapping.ListLayoutElements(mxd, "LEGEND_ELEMENT", "Legende")[0]
legend.autoAdd = True
Count_BTYP = RemoveDuplicates(Spalte_auslesen(join_bt, "BTYP_K"))
if len(Count_BTYP) > 70:
  legend.adjustColumnCount(2)
del Count_BTYP

# h)LOGO ----------------------------------------------------------------------------------------------------------------
for elm in arcpy.mapping.ListLayoutElements(mxd, "PICTURE_ELEMENT"):
    if elm.name == "Logo":
      if arcpy.Exists(logo_path):
        elm.sourceImage = logo_path
        
# i) KOPIE SPEICHERN ----------------------------------------------------------------------------------------------------------------
mxd.saveACopy(path + os.sep + Ergebnis_MXD_Name)

# j) ÜBERFLÜSSIGE SHAPEFILES LÖSCHEN ----------------------------------------------------------------------------------------------------------------
if arcpy.Exists(df_export_shp_ETRS):
    arcpy.Delete_management (df_export_shp_ETRS)
if arcpy.Exists(dp_export_shp_ETRS):
    arcpy.Delete_management (dp_export_shp_ETRS)
if arcpy.Exists(dl_export_shp_ETRS):
    arcpy.Delete_management (dl_export_shp_ETRS)
del mxd           



