# -*- coding: utf-8 -*-
#Projektarbeit: Automatisierte Kartenerstellung für MAKOs in ArcGIS10 mittels Python-Programmierung
#Erstellt im Rahmen der Zusatzqualifikation „Geographische Informationssysteme“ 2011/2012 - GIS-Trainees
#Autor: K.Fleckenstein 2012
#Thema: Automatisiert über ein Tool werden Kürzel von Tiernamen (abgeleitet vom deutschen Artnamen) aus einer Tabelle ausgelesen
#       und in die Tabellen mako-ft.dbf sowie mak-mas.dbf eingetragen, für die maßnahmenrelevanten Pflanzenarten sowie Zielarten
#       werden Kürzel aus dem wissenschaftlichen Namen erzeugt und in die Tabellen mako-fp.dbf sowie mako-mas.dbf eingetragen.
#       Falls die Spalten schon händisch ausgefüllt wurden, werden diese Werte nicht überschrieben.
#       
#Auftraggeber: LANUV NRW, Abteilung 2, Fachbereich 23 


#MODULE-----------------------------------------------------------------------------------------------------------------------------------------------
import arcpy, os, datetime

###PARAMETER
table_export_folder = arcpy.GetParameterAsText(0)
tierkuerzel_tabelle = arcpy.GetParameterAsText(1)#"Y:\Projekte\Externe\Abt2\Praktikanten\Fleckenstein_Katja\Projekt_MAKO_Karten" + os.sep + "Tierartenkuerzel.dbf"

#VARIABLEN
table_mako_fp = table_export_folder + os.sep + "mako-fp.dbf"
table_mako_ft = table_export_folder + os.sep + "mako-ft.dbf"
table_mako_mas = table_export_folder + os.sep + "mako-mas.dbf"

#FUNKTION UM KUERZELTABELLE AUSZULESEN UND IN MAKO-FT.DBF TABELLE REINZUSCHREIBEN
if arcpy.Exists(tierkuerzel_tabelle):
    rows = arcpy.SearchCursor(tierkuerzel_tabelle)#SEARCH CURSOR UM TIERKÜRZEL AUS KÜRZELTABELLE AUSZULESEN
    Tier_Dictionary = {}#LEGT EIN NEUES DICTIONARY AN
    for row in rows:
        Tier_Art_D = row.getValue("TIERART_D")
        Tier_Kuerzel = row.getValue("KUERZEL")
        Tier_Dictionary[Tier_Art_D]= Tier_Kuerzel
    del rows

print len(Tier_Dictionary.keys())
print len(Tier_Dictionary.values())


if arcpy.Exists(table_mako_ft):
    rows = arcpy.UpdateCursor(table_mako_ft)#UPDATE CURSOR UM TIERKÜRZEL AUS DICTIONARY IN MAKO-FT.DBF (SPALTE: TIERART)ZU SCHREIBEN
    for row in rows:
        new_row = row.getValue("TIERART_D").strip("; ")
        row.setValue("TIERART_D", new_row)
        new_row = row.getValue("TIERART_W").strip("; ")
        row.setValue("TIERART_W", new_row)
        rows.updateRow(row)
        
        Liste_Zeile = row.getValue("TIERART_D").split("; ")
        Kuerzel_Text = ""
        for Tier_Name in Liste_Zeile:
            if Tier_Name in Tier_Dictionary:
                Kuerzel_Text = Kuerzel_Text + Tier_Dictionary[Tier_Name] + "; "
            elif Tier_Name == "" or Tier_Name == " ":
                Kuerzel_Text = "; "          
            else:
                Kuerzel_Text = Kuerzel_Text + "N/A" + "; "

        if row.getValue("TIERART")== " " or row.getValue("TIERART")== "":
            row.setValue("TIERART", Kuerzel_Text[:-2])            
        rows.updateRow(row)
    del rows
    
#FUNKTION UM KUERZELTABELLE AUSZULESEN UND IN MAKO-MAS.DBF TABELLE BEI ZIELARTEN TIERKUERZEL EINZUTRAGEN
if arcpy.Exists(table_mako_mas):
    rows = arcpy.UpdateCursor(table_mako_mas)#UPDATE CURSOR UM TIERKÜRZEL AUS DICTIONARY IN MAKO-MAS.DBF (SPALTE: Z_ART_TI)ZU SCHREIBEN

    for row in rows:
        new_row = row.getValue("Z_ART_TI_D").strip("; ")
        row.setValue("Z_ART_TI_D", new_row)
        new_row = row.getValue("Z_ART_TI_W").strip("; ")
        row.setValue("Z_ART_TI_W", new_row)
        rows.updateRow(row)

        Liste_Zeile = row.getValue("Z_ART_TI_D").split("; ")

        Kuerzel_Text = ""
        for Tier_Name in Liste_Zeile:
            if Tier_Name in Tier_Dictionary:
                Kuerzel_Text = Kuerzel_Text + Tier_Dictionary[Tier_Name] + "; "
            elif Tier_Name not in Tier_Dictionary and Tier_Name != "":
                Kuerzel_Text = Kuerzel_Text + "N/A" + "; "

        if row.getValue("Z_ART_TI")== " " and row.getValue("Z_ART_TI_D")!= " ":
            row.setValue("Z_ART_TI", Kuerzel_Text[:-2])
        elif row.getValue("Z_ART_TI")== "" and row.getValue("Z_ART_TI_D")!= "":
            row.setValue("Z_ART_TI", Kuerzel_Text[:-2])
        rows.updateRow(row)
    del rows, Tier_Dictionary

# AUTOMATISCHES EINTRAGEN DER PFLANZENNAMEN-KUERZEL IN DIE DBF SACHTABELLE "mako-fp.dbf"
Pfl_Dictionary={}
if arcpy.Exists(table_mako_fp):
    rows = arcpy.UpdateCursor(table_mako_fp)#UPDATE CURSOR UM PFLANZENKÜRZEL IN MAKO-FP.DBF (SPALTE: PFL_ART) EINZUTRAGEN
    
    for row in rows:
        new_row = row.getValue("PFL_ART_D").strip("; ")
        row.setValue("PFL_ART_D", new_row)
        new_row = row.getValue("PFL_ART_W").strip("; ")
        row.setValue("PFL_ART_W", new_row)
        rows.updateRow(row)
        
        Liste_Zeile = row.getValue("PFL_ART_W").split(";")        
        Kuerzel_Text = ""
        for Pfl_Name in Liste_Zeile:
            if Pfl_Name.strip() in Pfl_Dictionary:
                Kurzname = Pfl_Dictionary[Pfl_Name.strip()]
                
            else:        
                Gattung_Art = Pfl_Name.strip().split(" ")
                Gattung = Gattung_Art[0]

                if len(Gattung_Art) > 1:
                    Gattung = Gattung_Art[0]
                    if len(Gattung_Art) >1:
                        Art = Gattung_Art[1]      
                    Kurzname = Gattung[0:2] + Art[0:1]
                    if Kurzname in Pfl_Dictionary.values():
                        Kurzname = Gattung[0:2] + Art[0:1].upper()
                        if Kurzname in Pfl_Dictionary.values():
                            Kurzname = Gattung[0:2] + Art[0:1].upper() + Art[1:2]
                            if Kurzname in Pfl_Dictionary.values():
                                Kurzname = Gattung[0:2] + Art[0:1].upper() + Art[len(Art)-1:]
                                if Kurzname in Pfl_Dictionary.values():
                                    Kurzname = "N/A"
                        
                elif len(Gattung_Art) == 1:
                    Gattung = Gattung_Art[0]
                    Kurzname = Gattung[0:2]
                    if Kurzname in Pfl_Dictionary.values():
                        Kurzname = Gattung[0:2].upper()
                Pfl_Dictionary[Pfl_Name.strip()] = Kurzname
                
            Kuerzel_Text= Kuerzel_Text + Kurzname + "; "
            
        if row.getValue("PFL_ART") == " " or row.getValue("PFL_ART") == "" :         
            row.setValue("PFL_ART", Kuerzel_Text[:-2])
        rows.updateRow(row)
    del rows

# AUTOMATISCHES EINTRAGEN DER PFLANZENNAMEN-KUERZEL IN DIE DBF SACHTABELLE "mako-mas.dbf"
if arcpy.Exists(table_mako_mas):
    rows = arcpy.UpdateCursor(table_mako_mas)#UPDATE CURSOR UM PFANZENKÜRZEL AUS DICTIONARY IN MAKO-MAS.DBF (SPALTE: Z_ART_PF) ZU SCHREIBEN

    for row in rows:
        new_row = row.getValue("Z_ART_PF_W").strip("; ")
        row.setValue("Z_ART_PF_W", new_row)
        new_row = row.getValue("Z_ART_PF_D").strip("; ")
        row.setValue("Z_ART_PF_D", new_row)
        rows.updateRow(row)
        
        Liste_Zeile = row.getValue("Z_ART_PF_W").split(";")       
        Kuerzel_Text = ""
        for Pfl_Name in Liste_Zeile:
            if Pfl_Name.strip() in Pfl_Dictionary:
                Kurzname = Pfl_Dictionary[Pfl_Name.strip()]
                
            else:         
                Gattung_Art = Pfl_Name.strip().split(" ")
                Gattung = Gattung_Art[0]

                if len(Gattung_Art) > 1:
                    Gattung = Gattung_Art[0]
                    Art = Gattung_Art[1]      
                    Kurzname = Gattung[0:2] + Art[0:1]
                    
                    if Kurzname in Pfl_Dictionary.values():
                        Kurzname = Gattung[0:2] + Art[0:1].upper()
                        if Kurzname in Pfl_Dictionary.values():
                            Kurzname = Gattung[0:2] + Art[0:1].upper() + Art[1:2]
                            if Kurzname in Pfl_Dictionary.values():
                                Kurzname = Gattung[0:2] + Art[0:1].upper() + Art[len(Art)-1:]
                                if Kurzname in Pfl_Dictionary.values():
                                    Kurzname = "N/A"
                        
                elif len(Gattung_Art) == 1:
                    Gattung = Gattung_Art[0]
                    Kurzname = Gattung[0:2]
                    
                    if Kurzname in Pfl_Dictionary.values():
                        Kurzname = Gattung[0:2].upper()
                        if Kurzname in Pfl_Dictionary.values():
                            Kurzname = "N/A"
                            
                Pfl_Dictionary[Pfl_Name.strip()] = Kurzname
               
            Kuerzel_Text = Kuerzel_Text + Kurzname + "; "
        if row.getValue("Z_ART_PF") == " " and row.getValue("Z_ART_PF_W") != " ":           
            row.setValue("Z_ART_PF", Kuerzel_Text[:-2])
        elif row.getValue("Z_ART_PF")== "" and row.getValue("Z_ART_PF_W")!= "":
            row.setValue("Z_ART_PF", Kuerzel_Text[:-2])
        rows.updateRow(row)
    del rows, Pfl_Dictionary #NICHT MEHR BENÖTIGTE VARIABLE LÖSCHEN
