﻿# -*- coding: utf-8 -*-
#Projektarbeit: Automatisierte Kartenerstellung für MAKOs mittels Python-Programmierung
#Erstellt im Rahmen der Zusatzqualifikation „Geographische Informationssysteme“ 2011/2012 - GIS-Trainees
#Autor: K.Fleckenstein 2012
#Thema: Automatisiert über ein Tool werden MAKO-Maßnahmenkarten erstellt
#Auftraggeber: LANUV NRW, Abteilung 2, Fachbereich 23
#modifiziert 25.02.2013 in Rücksprache mit M. Erzner, EDV-Servicestelle der Biologischen Stationen NRW (0281-96252-19)
#Modifikation erfolgte zur Anpassung an die Umgebung von ArcGIS 10.1 

#MODULE-----------------------------------------------------------------------------------------------------------------------------------------------
import arcpy, os, datetime

#PARAMETER-----------------------------------------------------------------------------------------------------------------------------------------------
Gebietsname = arcpy.GetParameterAsText(0)

#JOIN TABLE-FOLDERPATH:
table_export_folder = arcpy.GetParameterAsText(1)

#INPUT SHAPEFILES:
df_export_shp= arcpy.GetParameterAsText(2)
dp_export_shp= arcpy.GetParameterAsText(3)
dl_export_shp= arcpy.GetParameterAsText(4)

#MXD VORLAGE, SYMBOLOGIE_LAYER, LOGO:
mxd_path = arcpy.GetParameterAsText(5)
bt_symbology_lyr = arcpy.GetParameterAsText(6)
logo_path = arcpy.GetParameterAsText(7)

#AUSGABEORDNER/WORKSPACE:
path= arcpy.GetParameterAsText(8)

#=======================================================================================================================================================
#WORKSPACE-----------------------------------------------------------------------------------------------------------------------------------------------
arcpy.env.overwriteOutput = True
arcpy.env.workspace = path 
print arcpy.env.workspace

''' GELÖSCHT:
coordinate_path = os.path.join(arcpy.GetInstallInfo()["InstallDir"], "Coordinate Systems\Projected Coordinate Systems\UTM\Europe")
print coordinate_path
'''

'''EINGEFÜGT:
# SET OUTPUT COORDINATE SYSTEM
outCS = arcpy.SpatialReference('ETRS 1989 UTM Zone 32N')
'''

# SET OUTPUT COORDINATE SYSTEM
outCS = arcpy.SpatialReference('ETRS 1989 UTM Zone 32N')

# Ursprüngliche Feldnamen (Spaltennamen) werden beim Join von Shapefile und Tabelle beibehalten, ohne dass der Name der Ursprungstabelle vorangestellt wird
arcpy.env.qualifiedFieldNames = "UNQUALIFIED"

#VARIABLEN-----------------------------------------------------------------------------------------------------------------------------------------------
#MXDs
Datum = str(datetime.date.today()).replace("-","_") #Heutiges Datum mit im Format "Jahr_Monat_Tag"
Ergebnis_MXD_Name = "Massnahmenkarte" + "_" + Gebietsname + "_" + Datum + ".mxd"
print Ergebnis_MXD_Name

#DATENORDNER
folder_name = "Massnahmenkarte" + "_" + Gebietsname + "_" + Datum + "_Daten_ETRS"
folder_path =  path + os.sep + folder_name

#----JOIN SACHDATEN MIT GEODATEN--------------------------
#JOIN TABLES:
table_mako_bt = table_export_folder + os.sep + "mako-bt.dbf" 
table_mako_mas = table_export_folder + os.sep + "mako-mas.dbf"

#ETRS SHAPEFILES:
df_export_shp_ETRS = folder_path + os.sep + Gebietsname + "_" + df_export_shp[len(df_export_shp)-6:len(df_export_shp)-4] + "_ETRS.shp"
dp_export_shp_ETRS = folder_path + os.sep + Gebietsname + "_"+ dp_export_shp[len(dp_export_shp)-6:len(dp_export_shp)-4] + "_ETRS.shp"
if arcpy.Exists(dl_export_shp): 
  dl_export_shp_ETRS = folder_path + os.sep + Gebietsname + "_"+ dl_export_shp[len(dl_export_shp)-6:len(dl_export_shp)-4] + "_ETRS.shp"
else:
  dl_export_shp_ETRS=""

#JOIN OUTPUT SHAPEFILES:
join_bt = folder_path + os.sep + "mako_bt_df.shp"
join_mas = folder_path + os.sep + "mako_mas_df.shp"
join_dl = folder_path + os.sep + "mako_dl.shp"

joinField = "KENNUNG"
drop_fields = [joinField+"_1"] 

#WEITERE NEUE SHAPEFILES
FFH_Shape = folder_path + os.sep + "mako_FFH_Grenze.shp"
GB_Shape_temp = folder_path + os.sep + "mako_GB_Grenze_temp.shp"
GB_Shape = folder_path + os.sep + "mako_GB_Grenze.shp"
LRT_Shape = folder_path + os.sep + "mako_LRT_Grenze.shp"
Z_ART_TI_Shape_temp = folder_path + os.sep + "Z_ART_TI_temp.shp"
Z_ART_TI_table = "Z_ART_TI_table.dbf"
Z_ART_TI_Shape = folder_path + os.sep + "mako_Z_ART_TI.shp"
Z_ART_PF_Shape_temp = folder_path + os.sep + "Z_ART_PF_temp.shp"
Z_ART_PF_table = "Z_ART_PF_table.dbf"
Z_ART_PF_Shape = folder_path + os.sep + "mako_Z_ART_PF.shp"
#=======================================================================================================================================================
#FUNKTIONEN-----------------------------------------------------------------------------------------------------------------------------------------------
def newLine(): 
  return "\n"
  
#FUNKTION UM SACHDATEN MIT GEODATEN ZU VERKNÜPFEN
def addJoin(in_fc, joinField, join_table, join_type, out_fc, drop_fields):
    #JOIN DER SACHTABELLEN AN DAS SHAPEFILE 
    temp_layer = "temp.lyr"
    arcpy.MakeFeatureLayer_management (in_fc, temp_layer)
    arcpy.AddJoin_management (temp_layer, joinField, join_table, joinField, join_type)
    #ERZEUGEN EINER NEUEN FC AUS DEM TEMPORAEREN JOIN
    arcpy.CopyFeatures_management(temp_layer, out_fc)
    arcpy.DeleteField_management (out_fc, drop_fields)
    del temp_layer

#FUNKTION UM NEUEN ORDNER ANZULEGEN
def CreateNewFolder(current_workspace, folder_name):
    Liste = arcpy.ListFiles() 
    if folder_name not in Liste:
        arcpy.CreateFolder_management(arcpy.env.workspace, folder_name)       

'''GELÖSCHT:	
#FUNKTION ZUM TRANSFORMIEREN VON GAUSS-KRUEGER IN ETRS89
def transformation(fc):
    desc = arcpy.Describe(fc)
    coordinate = str(int(desc.extent.XMax))
    coordinate_system = desc.SpatialReference.name
    print desc.SpatialReference.name
    if len(coordinate) == 7:
        if coordinate[:1] in ["2", "3", "4", "5"]:
            if coordinate_system[:len(coordinate_system)-2] == "DHDN_3_Degree_Gauss_Zone" or coordinate_system[:len(coordinate_system)-2] == "Germany_Zone":
                #TEMP & REAL NAMEN ERZEUGEN 
                out_name = folder_path + os.sep + Gebietsname + "_" + fc[len(fc)-6:len(fc)-4] + "_ETRS.shp"
                #TRANSFORMIEREN
                arcpy.Project_management (fc, out_name, coordinate_path + os.sep +  "ETRS 1989 UTM Zone 32N.prj", "DHDN_To_ETRS_1989_8_NTv2")                
    del desc, coordinate, coordinate_system
'''		
'''EINGEFÜGT:
#FUNKTION ZUM TRANSFORMIEREN VON GAUSS-KRUEGER IN ETRS89
def transformation(fc):
    desc = arcpy.Describe(fc)
    coordinate = str(int(desc.extent.XMax))
    coordinate_system = desc.SpatialReference.name
    print desc.SpatialReference.name
    if len(coordinate) == 7:
        if coordinate[:1] in ["2", "3", "4", "5"]:
            if coordinate_system[:len(coordinate_system)-2] == "DHDN_3_Degree_Gauss_Zone" or coordinate_system[:len(coordinate_system)-2] == "Germany_Zone":
                #TEMP & REAL NAMEN ERZEUGEN 
                out_name = folder_path + os.sep + Gebietsname + "_" + fc[len(fc)-6:len(fc)-4] + "_ETRS.shp"
                #TRANSFORMIEREN
                arcpy.Project_management (fc, out_name, outCS, "DHDN_To_ETRS_1989_8_NTv2")          
    del desc, coordinate, coordinate_system
	'''

#FUNKTION ZUM TRANSFORMIEREN VON GAUSS-KRUEGER IN ETRS89
def transformation(fc):
    desc = arcpy.Describe(fc)
    coordinate = str(int(desc.extent.XMax))
    coordinate_system = desc.SpatialReference.name
    print desc.SpatialReference.name
    if len(coordinate) == 7:
        if coordinate[:1] in ["2", "3", "4", "5"]:
            if coordinate_system[:len(coordinate_system)-2] == "DHDN_3_Degree_Gauss_Zone" or coordinate_system[:len(coordinate_system)-2] == "Germany_Zone":
                #TEMP & REAL NAMEN ERZEUGEN 
                out_name = folder_path + os.sep + Gebietsname + "_" + fc[len(fc)-6:len(fc)-4] + "_ETRS.shp"
                #TRANSFORMIEREN
                arcpy.Project_management (fc, out_name, outCS, "DHDN_To_ETRS_1989_8_NTv2")         
    del desc, coordinate, coordinate_system

    
#FUNKTION ZUM ERZEUGEN NEUER SHAPEFILES AUS DEM EXPORT SHAPEFILE ÜBER SELEKTION
def NewShapeFromSelection(in_shape, where_clause, out_shape, label):       
    #LAYER ERZEUGEN ÜBER SELEKTION
    temp_layer = "temp.lyr"
    arcpy.MakeFeatureLayer_management (in_shape, temp_layer)
    arcpy.SelectLayerByAttribute_management (temp_layer, "NEW_SELECTION", where_clause)

    #ERZEUGEN EINER NEUEN FC AUS DEM TEMPORAEREN LAYER
    arcpy.CopyFeatures_management(temp_layer, out_shape)
    del temp_layer

    #NEUE SPALTE EINFÜGEN UND BESCHRIFTUNGSTEXT ÜBER UPDATE-CURSOR EINTRAGEN
    arcpy.AddField_management(out_shape, "NAME", "TEXT")
    rows= arcpy.UpdateCursor(out_shape, "", "", "NAME")
    for row in rows:
        row.setValue("NAME", label)
        rows.updateRow(row)
        del row
    del rows
    
#FUNKTION UM MEHRFACH VORKOMMENDE WERTE IN EINER LISTE ZU LÖSCHEN UND DIE LISTE ALPHABETISCH ZU SORTIEREN
def RemoveDuplicates(wordList):
    wordList2 =[]
    for word in wordList:
        if word not in wordList2 and word not in " ,;":         
            wordList2.append(word)
    wordList2.sort()
    return wordList2
  
#FUNKTION ZUM AUSLESEN VON SPALTEN, ERZEUGEN EINER LISTE FÜR DYNAMISCHE LEGENDEN-TEXTE
def Spalte_auslesen(Shapefile, Spalte):
    rows = arcpy.SearchCursor(Shapefile) 
    Liste=[]
    for row in rows:
        Liste_Zeile = row.getValue(Spalte).split(";")#TRENNUNG DER 1:N BEZIEHUNGEN
        for Eintrag in Liste_Zeile:
            Liste.append(Eintrag.lstrip())   
    del rows
    return Liste

#FUNKTION ZUM ERSTELLEN EINES LEGENDEN-TEXTES AUS EINER LISTE, DUPLIKATE WERDEN ENTFERNT, PRO EINTRAG DER LISTE --> EINE NEUE ZEILE 
def Textfeld_aus_Liste(Liste):
    Text= ""
    for Eintrag in Liste:
        Text = Text + Eintrag + newLine() #+ " " + newLine()
    return Text

#FUNKTION UM AUS DEM AKTUELLEN MASSTAB  DER KARTE, DER AUS DEM ZOOM AUF DIE AUSSENGRENZEN DES BT_LAYERS ENTSTEHT, EINEN AUFGERUNDETE GANZAHLIGEN MASSTBAB ZU ERMITTELN
def newScale(scale):
    scale_first_nr_plus1 = str(int(str(int(scale))[0])+1)
    scale_nulls =""
    for index in range(len(str(int(scale)))-1):
        scale_nulls = scale_nulls + "0"
    new_scale = int(scale_first_nr_plus1 + scale_nulls)
    return new_scale
  
#FUNKTION UM LEGENDENTEXTFELDER POSITIONIEREN
def SetPosition(Text1, header2, Text_2, Text_K_2):
    header2.elementPositionY = Text1.elementPositionY - Text1.elementHeight - 0.3
    Text_2.elementPositionY = header2.elementPositionY - header2.elementHeight - 0.1
    Text_K_2.elementPositionY = Text_2.elementPositionY
#===========================================================================================================================================================
# 1) NEUEN ORDNER ERSTELLEN
CreateNewFolder(arcpy.env.workspace, folder_name)
out_name = df_export_shp[:len(df_export_shp)-4] + "_ETRS.shp"

#=======================================================================================================================================================
# 2) TRANSFORMATION DER GEODATEN IN ETRS89, FALLS SIE IN GAUß-KRUEGER VORLIEGEN UND EXISTIEREN
if arcpy.Exists(df_export_shp):
    transformation(df_export_shp)
if arcpy.Exists(dp_export_shp):
    transformation(dp_export_shp)
if arcpy.Exists(dl_export_shp):
    transformation(dl_export_shp)

#=======================================================================================================================================================
# 3) JOIN DER SACHTABELLEN AN DAS SHAPEFILE --> ERZEUGEN VON NEUEN SHAPEFILES
if arcpy.Exists(df_export_shp_ETRS):
    addJoin(df_export_shp_ETRS, joinField, table_mako_mas, "KEEP_COMMON", join_mas, drop_fields)
    addJoin(df_export_shp_ETRS, joinField, table_mako_bt, "KEEP_COMMON", join_bt, drop_fields)
elif arcpy.Exists(df_export_shp):
    addJoin(df_export_shp, joinField, table_mako_mas, "KEEP_COMMON", join_mas, drop_fields)
    addJoin(df_export_shp, joinField, table_mako_bt, "KEEP_COMMON", join_bt, drop_fields)

if arcpy.Exists(dl_export_shp_ETRS):    
    addJoin(dl_export_shp_ETRS, joinField, table_mako_bt, "KEEP_ALL", join_dl, drop_fields)
elif arcpy.Exists(dl_export_shp):
    addJoin(dl_export_shp, joinField, table_mako_bt, "KEEP_ALL", join_dl, drop_fields)
    
#=======================================================================================================================================================
# 4) ERZEUGEN NEUER SHAPEFILES DURCH SELEKTION VON BESTIMMTEN DATEN AUS EXPORT_SHAPEFILES 

# a) FFH-GRENZE --> NEUES SHAPEFILES ERZEUGEN-----------------------------------------------------------------------------------------------------
if arcpy.Exists(df_export_shp_ETRS):
    NewShapeFromSelection(df_export_shp_ETRS, "KENNUNG LIKE 'DE-%'", FFH_Shape, "Grenze FFH-Gebiet")
elif arcpy.Exists(df_export_shp):
    NewShapeFromSelection(df_export_shp, "KENNUNG LIKE 'DE-%'", FFH_Shape, "Grenze FFH-Gebiet")
    
# b) FFH-LRT-GEBIETE --> NEUES SHAPEFILES ERZEUGEN------------------------------------------------------------------------------------------------
NewShapeFromSelection(join_bt, "BTYP_K LIKE 'x%' OR BTYP_K LIKE 'z%' ", LRT_Shape, "FFH-Lebensraumtyp")

# c) GB_GRENZEN, NEUES SHAPEFILES ERZEUGEN-------------------------------------------------------------------------------------------------------
if arcpy.Exists(df_export_shp_ETRS):
    NewShapeFromSelection(df_export_shp_ETRS, "KENNUNG LIKE 'GB-%'", GB_Shape_temp, "§ 62 Biotop")
elif arcpy.Exists(df_export_shp):
    NewShapeFromSelection(df_export_shp, "KENNUNG LIKE 'GB-%'", GB_Shape_temp, "§ 62 Biotop")
#SPATIAL JOIN BT --> GB
arcpy.SpatialJoin_analysis (GB_Shape_temp, join_bt, GB_Shape, "","","","CONTAINS")

#NICHT BENÖTIGTE FELDER (SPALTEN) RAUSLÖSCHEN
FieldList= arcpy.ListFields(GB_Shape)
dropFieldList=[]
for field in FieldList:
    if field.name not in ["FID", "Shape","KENNUNG", "GISPADID", "KLASSE", "GEOFUNK", "NAME", "KENNUNG_1", "P62_TYP_K", "P62_TYP"]:
        dropFieldList.append(field.name)
arcpy.DeleteField_management(GB_Shape, dropFieldList)

#TEMPORÄRES SHAPEFILE LÖSCHEN
if arcpy.Exists(GB_Shape_temp):
    arcpy.Delete_management (GB_Shape_temp)
del GB_Shape_temp

if arcpy.Exists(join_bt):
    arcpy.Delete_management (join_bt)
del join_bt
#===========================================================================================================================================================
# 5) AUTOMATISIERTE KARTENERSTELLUNG 

# a) MXD LADEN----------------------------------------------------------------------------------------------------------------------------
mxd = arcpy.mapping.MapDocument(mxd_path)
mxd.activeView = "PAGE_LAYOUT"

# b)REPAIR WORKSPACE
mxd.findAndReplaceWorkspacePaths("", folder_path)

# c) DATAFRAME----------------------------------------------------------------------------------------------------------------------------
df = arcpy.mapping.ListDataFrames(mxd)[0]

# d) AUSWAHL, ZOOM DES DATAFRAMES AUF DEN BIOTOPTYPEN-BESTAND-LAYER, FESTLEGEN DES BEZUGSMAßSTABS
for lyr in arcpy.mapping.ListLayers(mxd, "", df):
    #ZOOM
    if lyr.name == "Ziel-Biotoptypen":
        arcpy.SelectLayerByAttribute_management (lyr, "NEW_SELECTION")
        df.zoomToSelectedFeatures()
        arcpy.SelectLayerByAttribute_management (lyr, "CLEAR_SELECTION")
        if arcpy.Exists(bt_symbology_lyr):          
            arcpy.ApplySymbologyFromLayer_management(lyr, bt_symbology_lyr)

df.scale = newScale(df.scale)
df.referenceScale = df.scale
print int(df.scale)

if arcpy.Exists(dl_export_shp):
    arcpy.MakeFeatureLayer_management(join_dl, "dl_export")
    add_layer = arcpy.mapping.Layer("dl_export")
    arcpy.mapping.AddLayer(df, add_layer, "TOP")
    
# e) DYNAMISCHE TEXTE FÜR DIE KARTEN_LEGENDE ERSTELLEN-------------------------------------------------------------------------------------------

#FFH-KENNUNG AUSLESEN UND IN VARIABLE SPEICHERN FÜR DYNAMISCHEN TEXT 
rows = arcpy.SearchCursor(FFH_Shape, "KENNUNG LIKE 'DE-%'") 
FFH_KENNUNG=""
for row in rows:
    FFH_KENNUNG = row.getValue("KENNUNG")       
del rows

#SPALTEN AUSLESEN UND IN VARIABLEN SPEICHERN FÜR DYNAMISCHE TEXTE
#TEXTFELD MIT KÜRZEL UND DEUTSCHEM NAMEN DER TIERARTEN
ft_kurz_Liste = Spalte_auslesen(table_mako_mas, "Z_ART_TI")
ft_lang_Liste = Spalte_auslesen(table_mako_mas, "Z_ART_TI_D")
print len(ft_kurz_Liste), len(ft_lang_Liste)
ft_Text_beide=""
Tier_Liste=[]

for index in range(len(ft_lang_Liste)):
    if ft_lang_Liste[index] == " " or ft_lang_Liste[index] == "" :
        ft_Text_beide = " "
    elif len(ft_kurz_Liste) != len(ft_lang_Liste):
        ft_Text_beide = "N/A" + " " + ft_lang_Liste[index]
    elif ft_kurz_Liste[index] == "" or ft_kurz_Liste[index] == " ":
        ft_Text_beide = "N/A" + " " + ft_lang_Liste[index]
    else:
        ft_Text_beide = ft_kurz_Liste[index] + " " + ft_lang_Liste[index]
    Tier_Liste.append (ft_Text_beide)
del ft_Text_beide   

ft_lang_Liste=[]
ft_kurz_Liste=[]

for Eintrag in RemoveDuplicates(Tier_Liste):
  index =Eintrag.find(" ")
  ft_lang_Liste.append(Eintrag[index+1:])
  ft_kurz_Liste.append(Eintrag[:index])

Z_ART_TI_D_Text = Textfeld_aus_Liste(ft_lang_Liste)#LANGNAMEN DER TIERARTEN
Z_ART_TI_Text = Textfeld_aus_Liste(ft_kurz_Liste)#KÜRZEL DER TIERARTEN

#SPALTEN AUSLESEN UND IN VARIABLEN SPEICHERN FÜR DYNAMISCHE TEXTE
#TEXTFELD MIT KÜRZEL UND WISSSENSCHAFTLICHEN NAMEN DER PFLANZENARTEN
fp_kurz_Liste = Spalte_auslesen(table_mako_mas, "Z_ART_PF")
fp_lang_Liste = Spalte_auslesen(table_mako_mas, "Z_ART_PF_W")
print len(ft_kurz_Liste), len(ft_lang_Liste)
Pflanzen_Liste=[]
fp_Text_beide =""
for index in range(len(fp_lang_Liste)):
    if fp_lang_Liste[index] == " " or fp_lang_Liste[index] == "" :
        fp_Text_beide = " "
    elif len(fp_kurz_Liste) != len(fp_lang_Liste):
        fp_Text_beide = "N/A" + " " + fp_lang_Liste[index]
    elif fp_kurz_Liste[index] == "" or fp_kurz_Liste[index] == " ":
        fp_Text_beide = "N/A" + " " + fp_lang_Liste[index]
    else:
        fp_Text_beide = fp_kurz_Liste[index] + " " + fp_lang_Liste[index]
    Pflanzen_Liste.append (fp_Text_beide)
del fp_Text_beide    

fp_lang_Liste=[]
fp_kurz_Liste=[]
for Eintrag in RemoveDuplicates(Pflanzen_Liste):
  index =Eintrag.find(" ")
  fp_lang_Liste.append(Eintrag[index+1:])
  fp_kurz_Liste.append(Eintrag[:index])
Z_ART_PF_W_Text = Textfeld_aus_Liste(fp_lang_Liste)#LANGNAMEN DER PLFANZENARTEN
Z_ART_PF_Text= Textfeld_aus_Liste(fp_kurz_Liste)#KÜRZEL DER PFLANZENARTEN

        
#DYNAMISCHE TEXTE AUF KARTEN_LAYOUT AKTUALISIEREN  (ALLGEMEINE UND ZIELARTEN)
for elm in arcpy.mapping.ListLayoutElements(mxd, "TEXT_ELEMENT"):
    if elm.name == "Gebietsname":
        if len(Gebietsname)!= 0:
            elm.text = Gebietsname
    elif elm.name == "Gebietsnummer":
        if len(FFH_KENNUNG)!= 0:
            elm.text = FFH_KENNUNG
    elif elm.name == "Z_ART_TI":
        Z_ART_TI = elm
        if len(Z_ART_TI_Text)!= 0:
            elm.text = Z_ART_TI_Text
    elif elm.name == "Z_ART_TI_D":
        Z_ART_TI_D = elm
        if len(Z_ART_TI_D_Text)!= 0:
            elm.text = Z_ART_TI_D_Text      
    elif elm.name == "Z_ART_PF":
        Z_ART_PF = elm
        if len(Z_ART_PF_Text)!= 0:
            elm.text = Z_ART_PF_Text
    elif elm.name == "Z_ART_PF_W":
        Z_ART_PF_W = elm
        if len(Z_ART_PF_W_Text)!= 0:
            elm.text = Z_ART_PF_W_Text
del Z_ART_TI_Text, Z_ART_TI_D_Text, Z_ART_PF_Text, Z_ART_PF_W_Text

#DYNAMISCHEN TEXT FÜR MASSNAHMEN ERSTELLEN, SORTIERT NACH NUMMER
MASSN = Spalte_auslesen(table_mako_mas, "MASSN")
MASSN_Liste = RemoveDuplicates(MASSN)

MASSN_Text_1= ""
MASSN_K_Text_1= ""
MASSN_Text_2= ""
MASSN_K_Text_2= ""
MASSN_Text_3= ""
MASSN_K_Text_3= ""
MASSN_Text_4= ""
MASSN_K_Text_4= ""
MASSN_Text_5 = ""
MASSN_K_Text_5 = ""
MASSN_Text_6= ""
MASSN_K_Text_6= ""
MASSN_Text_7= ""
MASSN_K_Text_7= ""
MASSN_Text_8= ""
MASSN_K_Text_8= ""
MASSN_Text_9= ""
MASSN_K_Text_9= ""
MASSN_Text_10 = ""
MASSN_K_Text_10 = ""
MASSN_Text_11= ""
MASSN_K_Text_11= ""
MASSN_Text_12= ""
MASSN_K_Text_12= ""
MASSN_Text_13 = ""
MASSN_K_Text_13 = ""
MASSN_Text_14 = ""
MASSN_K_Text_14 = ""
   
for Eintrag in MASSN_Liste:
  if Eintrag[:2] == "1.":
    MASSN_Text_1 = MASSN_Text_1 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_1 = MASSN_K_Text_1 + Eintrag[:index] + newLine()
  elif Eintrag[:2] =="2.":
    MASSN_Text_2 = MASSN_Text_2 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_2 = MASSN_K_Text_2 + Eintrag[:index] + newLine()
  elif Eintrag[:2] =="3.":
    MASSN_Text_3 = MASSN_Text_3 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_3 = MASSN_K_Text_3 + Eintrag[:index] + newLine()
  elif Eintrag[:2] =="4.":
    MASSN_Text_4 = MASSN_Text_4 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_4 = MASSN_K_Text_4 + Eintrag[:index] + newLine()
  elif Eintrag[:2] == "5.":
    MASSN_Text_5 = MASSN_Text_5 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_5 = MASSN_K_Text_5 + Eintrag[:index] + newLine()
  elif Eintrag[:2] =="6.":
    MASSN_Text_6 = MASSN_Text_6 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_6 = MASSN_K_Text_6 + Eintrag[:index] + newLine()
  elif Eintrag[:2] =="7.":
    MASSN_Text_7 = MASSN_Text_7 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_7 = MASSN_K_Text_7 + Eintrag[:index] + newLine()
  elif Eintrag[:2] =="8.":
    MASSN_Text_8 = MASSN_Text_8 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_8 = MASSN_K_Text_8 + Eintrag[:index] + newLine()
  elif Eintrag[:2] =="9.":
    MASSN_Text_9 = MASSN_Text_9 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_9 = MASSN_K_Text_9 + Eintrag[:index] + newLine()
  elif Eintrag[:3] =="10.":
    MASSN_Text_10 = MASSN_Text_10 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_10 = MASSN_K_Text_10 + Eintrag[:index] + newLine()
  elif Eintrag[:3] =="11.":
    MASSN_Text_11 = MASSN_Text_11 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_11 = MASSN_K_Text_11 + Eintrag[:index] + newLine()
  elif Eintrag[:3] =="12.":
    MASSN_Text_12 = MASSN_Text_12 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_12 = MASSN_K_Text_12 + Eintrag[:index] + newLine()
  elif Eintrag[:3] =="13.":
    MASSN_Text_13 = MASSN_Text_13 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_13 = MASSN_K_Text_13 + Eintrag[:index] + newLine()
  elif Eintrag[:3] =="14.":
    MASSN_Text_14 = MASSN_Text_14 + Eintrag.lstrip("1234567890.? ") + newLine()
    index=Eintrag.find(" ")
    MASSN_K_Text_14 = MASSN_K_Text_14 + Eintrag[:index] + newLine()        
del MASSN_Liste, MASSN
        
#MASSNAHMEN TEXTE AUF KARTEN_LAYOUT AKTUALISIEREN  
for elm in arcpy.mapping.ListLayoutElements(mxd, "TEXT_ELEMENT", "MASSN*"):            
    if elm.name == "MASSN_K":
        if len(MASSN_K_Text)!= 0:
            elm.text = MASSN_K_Text
        else:
            elm.text = " "            
    elif elm.name == "MASSN":
        if len(MASSN_Text)!= 0:
            elm.text = MASSN_Text
        else:
            elm.text = " "            
    elif elm.name == "MASSN_K_1":
        if len(MASSN_K_Text_1)!= 0:
            elm.text = MASSN_K_Text_1
        else:
            elm.text = " "            
    elif elm.name == "MASSN_1":
        MASSN_1 = elm
        if len(MASSN_Text_1)!= 0:
            elm.text = MASSN_Text_1
        else:
            elm.text = " "            
    elif elm.name == "MASSN_K_2":
        MASSN_K_2 = elm
        if len(MASSN_K_Text_2)!= 0:
            elm.text = MASSN_K_Text_2
        else:
            elm.text = " "            
    elif elm.name == "MASSN_2":
        MASSN_2 = elm
        if len(MASSN_Text_2)!= 0:
            elm.text = MASSN_Text_2
        else:
            elm.text = " "            
    elif elm.name == "MASSN_K_3":
        MASSN_K_3 = elm
        if len(MASSN_K_Text_3)!= 0:
            elm.text = MASSN_K_Text_3
        else:
            elm.text = " "            
    elif elm.name == "MASSN_3":
        MASSN_3 = elm
        if len(MASSN_Text_3)!= 0:
            elm.text = MASSN_Text_3
        else:
            elm.text = " "            
    elif elm.name == "MASSN_K_4":
        MASSN_K_4 = elm
        if len(MASSN_K_Text_4)!= 0:
            elm.text = MASSN_K_Text_4
        else:
            elm.text = " "            
    elif elm.name == "MASSN_4":
        MASSN_4 = elm
        if len(MASSN_Text_4)!= 0:
            elm.text = MASSN_Text_4
        else:
            elm.text = " "            
    elif elm.name == "MASSN_K_5":
        MASSN_K_5 = elm
        if len(MASSN_K_Text_5)!= 0:
            elm.text = MASSN_K_Text_5
        else:
            elm.text = " "            
    elif elm.name == "MASSN_5":
        MASSN_5 = elm
        if len(MASSN_Text_5)!= 0:
            elm.text = MASSN_Text_5
        else:
            elm.text = " "            
    elif elm.name == "MASSN_K_6":
        MASSN_K_6 = elm
        if len(MASSN_K_Text_6)!= 0:
            elm.text = MASSN_K_Text_6
        else:
            elm.text = " "            
    elif elm.name == "MASSN_6":
        MASSN_6 = elm
        if len(MASSN_Text_6)!= 0:
            elm.text = MASSN_Text_6
        else:
            elm.text = " "
    elif elm.name == "MASSN_K_7":
        MASSN_K_7 = elm
        if len(MASSN_K_Text_7)!= 0:
            elm.text = MASSN_K_Text_7
        else:
            elm.text = " "
    elif elm.name == "MASSN_7":
        MASSN_7 = elm
        if len(MASSN_Text_7)!= 0:
            elm.text = MASSN_Text_7
        else:
            elm.text = " "
    elif elm.name == "MASSN_K_8":
        MASSN_K_8 = elm
        if len(MASSN_K_Text_8)!= 0:
            elm.text = MASSN_K_Text_8
        else:
            elm.text = " "
    elif elm.name == "MASSN_8":
        MASSN_8 = elm
        if len(MASSN_Text_8)!= 0:
            elm.text = MASSN_Text_8
        else:
            elm.text = " "
    elif elm.name == "MASSN_K_9":
        MASSN_K_9 = elm
        if len(MASSN_K_Text_9)!= 0:
            elm.text = MASSN_K_Text_9
        else:
            elm.text = " "    
    elif elm.name == "MASSN_9":
        MASSN_9 = elm
        if len(MASSN_Text_9)!= 0:
            elm.text = MASSN_Text_9
        else:
            elm.text = " "
    elif elm.name == "MASSN_K_10":
        MASSN_K_10 = elm
        if len(MASSN_K_Text_10)!= 0:
            elm.text = MASSN_K_Text_10
        else:
            elm.text = " "
    elif elm.name == "MASSN_10":
        MASSN_10 = elm
        if len(MASSN_Text_10)!= 0:
            elm.text = MASSN_Text_10
        else:
            elm.text = " "
    elif elm.name == "MASSN_K_11":
        MASSN_K_11 = elm
        if len(MASSN_K_Text_11)!= 0:
            elm.text = MASSN_K_Text_11
        else:
            elm.text = " "
    elif elm.name == "MASSN_11":
        MASSN_11 = elm
        if len(MASSN_Text_11)!= 0:
            elm.text = MASSN_Text_11
        else:
            elm.text = " "
    elif elm.name == "MASSN_K_12":
        MASSN_K_12 = elm
        if len(MASSN_K_Text_12)!= 0:
            elm.text = MASSN_K_Text_12
        else:
            elm.text = " "
    elif elm.name == "MASSN_12":
        MASSN_12 = elm
        if len(MASSN_Text_12)!= 0:
            elm.text = MASSN_Text_12
        else:
            elm.text = " "
    elif elm.name == "MASSN_K_13":
        MASSN_K_13 = elm
        if len(MASSN_K_Text_13)!= 0:
            elm.text = MASSN_K_Text_13
        else:
            elm.text = " "
    elif elm.name == "MASSN_13":
        MASSN_13 = elm
        if len(MASSN_Text_13)!= 0:
            elm.text = MASSN_Text_13
        else:
            elm.text = " "
    elif elm.name == "MASSN_K_14":
        MASSN_K_14 = elm
        if len(MASSN_K_Text_14)!= 0:
            elm.text = MASSN_K_Text_14
        else:
            elm.text = " "
    elif elm.name == "MASSN_14":
        MASSN_14 = elm
        if len(MASSN_Text_14)!= 0:
            elm.text = MASSN_Text_14
        else:
            elm.text = " "
del MASSN_Text_1, MASSN_Text_2, MASSN_Text_3, MASSN_Text_4, MASSN_Text_5, MASSN_Text_6, MASSN_Text_7
del MASSN_Text_8, MASSN_Text_9, MASSN_Text_10, MASSN_Text_11, MASSN_Text_12, MASSN_Text_13, MASSN_Text_14
del MASSN_K_Text_1, MASSN_K_Text_2, MASSN_K_Text_3, MASSN_K_Text_4, MASSN_K_Text_5, MASSN_K_Text_6, MASSN_K_Text_7
del MASSN_K_Text_8, MASSN_K_Text_9, MASSN_K_Text_10, MASSN_K_Text_11, MASSN_K_Text_12, MASSN_K_Text_13, MASSN_K_Text_14

# f) ÜBERSCHRIFTEN DER MASSNAHMEN ALS VARIABLEN SPEICHERN FÜR POSITIONSBESTIMMUNG------------------------------------------------
for elm in arcpy.mapping.ListLayoutElements(mxd, "GRAPHIC_ELEMENT", "header*"):
    if elm.name == "header_ZI_PF":
        header_ZI_PF = elm
    elif elm.name == "header_MAS_NR":
        header_MAS_NR = elm
    elif elm.name == "header1":
        header1 = elm
    elif elm.name == "header2":
        header2 = elm
    elif elm.name == "header3":
        header3 = elm
    elif elm.name == "header4":
        header4 = elm
    elif elm.name == "header5":
        header5 = elm
    elif elm.name == "header6":
        header6 = elm
    elif elm.name == "header7":
        header7 = elm
    elif elm.name == "header8":
        header8 = elm
    elif elm.name == "header9":
        header9 = elm
        
for elm in arcpy.mapping.ListLayoutElements(mxd, "TEXT_ELEMENT", "header*"):
    if elm.name == "header10":
        header10 = elm
    elif elm.name == "header11":
        header11 = elm
    elif elm.name == "header12":
        header12 = elm
    elif elm.name == "header13":
        header13 = elm
    elif elm.name == "header14":
        header14 = elm

# g) POSITION DER EINZELNEN MASSNAHMEN SOWIE DER ÜBERSCHRIFTEN RELATIV ZUEINANDER FESTLEGEN------------------------------------------

SetPosition(MASSN_1, header2,  MASSN_2, MASSN_K_2)    
SetPosition(MASSN_2, header3,  MASSN_3, MASSN_K_3)
SetPosition(MASSN_3, header4, MASSN_4, MASSN_K_4)
SetPosition(MASSN_4, header5,  MASSN_5, MASSN_K_5)
SetPosition(MASSN_5, header6,  MASSN_6, MASSN_K_6)
SetPosition(MASSN_6, header7,  MASSN_7, MASSN_K_7)
SetPosition(MASSN_7, header8,  MASSN_8, MASSN_K_8)
SetPosition(MASSN_8, header9,  MASSN_9, MASSN_K_9)
SetPosition(MASSN_9, header10,  MASSN_10, MASSN_K_10)
SetPosition(MASSN_10, header11,  MASSN_11, MASSN_K_11)
SetPosition(MASSN_11, header12,  MASSN_12, MASSN_K_12)
SetPosition(MASSN_12, header13,  MASSN_13, MASSN_K_13)
SetPosition(MASSN_13, header14,  MASSN_14, MASSN_K_14)

#POSITIONIEREN DER ZIELARTEN_TEXTFELDER
try:
  header_ZI_PF.elementPositionY = Z_ART_TI_D.elementPositionY - Z_ART_TI_D.elementHeight - 3
  Z_ART_PF_W.elementPositionY = header_ZI_PF.elementPositionY - header_ZI_PF.elementHeight - 0.3
  Z_ART_PF.elementPositionY = Z_ART_PF_W.elementPositionY
  header_MAS_NR.elementPositionY = Z_ART_PF_W.elementPositionY - Z_ART_PF_W.elementHeight - 3
except:
  print "Positionieren fehlgeschlagen"
  
# h) LOGO EINFÜGEN----------------------------------------------------------------------------------------------------------------------------
for elm in arcpy.mapping.ListLayoutElements(mxd, "PICTURE_ELEMENT"):
    if elm.name == "Logo":
      if arcpy.Exists(logo_path):
        elm.sourceImage = logo_path
                            

# i) KOPIE DER MXD SPEICHERN--------------------------------------------------------------------------------------------------------------------
mxd.saveACopy(path + os.sep + Ergebnis_MXD_Name)
del mxd         

# j) ÜBERFLÜSSIGE SHAPEFILES LÖSCHEN-------------------------------------------------------------------------------------------------------------
if arcpy.Exists(df_export_shp_ETRS):
    arcpy.Delete_management (df_export_shp_ETRS)
if arcpy.Exists(dp_export_shp_ETRS):
    arcpy.Delete_management (dp_export_shp_ETRS)
if arcpy.Exists(dl_export_shp_ETRS):
    arcpy.Delete_management (dl_export_shp_ETRS)

